@@ -90,6 +90,10 @@
 
 #define  GLUT_STROKE_FONT_DRAW_JOIN_DOTS    0x0206  /* Draw dots between line segments of stroke fonts? */
 
+#define  GLUT_ALLOW_NEGATIVE_WINDOW_POSITION 0x0207 /* GLUT doesn't allow negative window positions by default */
+
+#define  GLUT_WINDOW_SRGB                   0x007D
+
 /*
  * New tokens for glutInitDisplayMode.
  * Only one GLUT_AUXn bit may be used at a time.
@@ -124,6 +128,16 @@
 #define GLUT_CORE_PROFILE                   0x0001
 #define	GLUT_COMPATIBILITY_PROFILE          0x0002
 
+/*
+* GLUT API Extension macro definitions -- Spaceball button definitions
+*/
+
+#define  GLUT_SPACEBALL_BUTTON_A            0x0001
+#define  GLUT_SPACEBALL_BUTTON_B            0x0002
+#define  GLUT_SPACEBALL_BUTTON_C            0x0004
+#define  GLUT_SPACEBALL_BUTTON_D            0x0008
+#define  GLUT_SPACEBALL_BUTTON_E            0x0010
+
 /*
  * Process loop function, see fg_main.c
  */
@@ -193,7 +207,7 @@ FGAPI void    FGAPIENTRY glutSolidTeaspoon( double size );
 /*
  * Extension functions, see fg_ext.c
  */
-typedef void (*GLUTproc)(void);
+typedef void (*GLUTproc)();
 FGAPI GLUTproc FGAPIENTRY glutGetProcAddress( const char *procName );
 
 /*
@@ -244,13 +258,13 @@ FGAPI void    FGAPIENTRY glutInitErrorFunc( void (* callback)( const char *fmt,
 FGAPI void    FGAPIENTRY glutInitWarningFunc( void (* callback)( const char *fmt, va_list ap ) );
 
 /* OpenGL >= 2.0 support */
-FGAPI void    FGAPIENTRY glutSetVertexAttribCoord3(GLint attrib);
-FGAPI void    FGAPIENTRY glutSetVertexAttribNormal(GLint attrib);
-FGAPI void    FGAPIENTRY glutSetVertexAttribTexCoord2(GLint attrib);
+FGAPI void    FGAPIENTRY glutSetVertexAttribCoord3( GLint attrib );
+FGAPI void    FGAPIENTRY glutSetVertexAttribNormal( GLint attrib );
+FGAPI void    FGAPIENTRY glutSetVertexAttribTexCoord2( GLint attrib );
 
 /* Mobile platforms lifecycle */
-FGAPI void    FGAPIENTRY glutInitContextFunc(void (* callback)(void));
-FGAPI void    FGAPIENTRY glutAppStatusFunc(void (* callback)(int));
+FGAPI void    FGAPIENTRY glutInitContextFunc( void (* callback)( void ) );
+FGAPI void    FGAPIENTRY glutAppStatusFunc( void (* callback)( int ) );
 /* state flags that can be passed to callback set by glutAppStatusFunc */
 #define GLUT_APPSTATUS_PAUSE                0x0001
 #define GLUT_APPSTATUS_RESUME               0x0002
@@ -262,6 +276,9 @@ FGAPI void    FGAPIENTRY glutAppStatusFunc(void (* callback)(int));
 #define  GLUT_BORDERLESS                    0x0800
 #define  GLUT_SRGB                          0x1000
 
+/* User-argument callbacks and implementation */
+#include "freeglut_ucall.h"
+
 #ifdef __cplusplus
     }
 #endif
